# PythonStack

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**requirements** | **str** | Direct dependencies for the application stack. |
**requirements_lock** | **str** | Fully pinned down dependency stack. |
**requirements_format** | **list[str]** | Lockfile format - defaults to pipenv if not explicitly specified.  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

